/*
 * EventEditor widget
 * Copyright (C) 1998 the Free Software Foundation
 *
 * Author: Miguel de Icaza (miguel@kernel.org)
 */

#ifndef __EVENT_EDITOR_H__
#define __EVENT_EDITOR_H__

#include <glib.h>

#include <gtk/gtkdialog.h>
#include <gtk/gtkwidget.h>

#include "gnome-cal.h"

G_BEGIN_DECLS

#define TYPE_EVENT_EDITOR		(event_editor_get_type ())
#define EVENT_EDITOR(obj)		(GTK_CHECK_CAST(obj, TYPE_EVENT_EDITOR, EventEditor))
#define EVENT_EDITOR_CLASS(class)	(GTK_CHECK_CAST_CLASS(class, TYPE_EVENT_EDITOR, EventEditorClass))
#define IS_EVENT_EDITOR(obj)		(GTK_CHECK_TYPE(obj, TYPE_EVENT_EDITOR))

typedef struct _EventEditor		EventEditor;
typedef struct _EventEditorClass	EventEditorClass;
typedef struct _EventEditorPriv		EventEditorPriv;

/* FIXME: most (all?) of the following should go into the private struct
 *        or vanish into local variables
 */
struct _EventEditor {
	GtkDialog   dialog;

        GtkWidget  *general;
        GtkWidget  *general_time_table;
	GtkWidget  *general_allday;
	GtkWidget  *general_owner;
	GtkWidget  *general_summary;
	GtkWidget  *general_radios;

	GtkWidget  *recur_page_label;
	GtkWidget  *recur_vbox;
	GtkWidget  *recur_hbox;

	GSList     *recur_rr_group;
	GtkWidget  *recur_rr_notebook;
	GtkWidget  *recur_rr_day_period;
	GtkWidget  *recur_rr_week_period;
	GtkWidget  *recur_rr_week_days [7];
	GtkWidget  *recur_rr_month_date;
	GtkWidget  *recur_rr_month_date_label;
	GtkWidget  *recur_rr_month_day;
	GtkWidget  *recur_rr_month_weekday;
	GtkWidget  *recur_rr_month_period;
	GtkWidget  *recur_rr_year_period;

	GSList     *recur_ed_group;
	GtkWidget  *recur_ed_end_after;

	GtkWidget  *recur_ex_vbox;
	GtkWidget  *recur_ex_list;
	
	/* The calendar owner of this event */
        GnomeCalendar *gnome_cal;

	EventEditorPriv *priv;
};

struct _EventEditorClass {
	GtkDialogClass parent_class;
};


GType		 event_editor_get_type		(void);
GtkWidget	*event_editor_new		(GnomeCalendar *owner, iCalObject *);

/* Convenience function to create a new event editor for an event
 * that goes from day_begin to day_end of the specified day.
 */
GtkWidget	*event_editor_new_whole_day	(GnomeCalendar *owner, time_t day);
 
G_END_DECLS

#endif /* __EVENTEDIT_H__ */
