/* Miscellaneous GNOME Card UI Functions
 * Copyright (C) 2002  Sebastian Rittau <srittau@jroger.in-berlin.de>
 *
 * $Id: gnomecard-ui.c,v 1.1.2.1 2002/05/19 19:32:58 srittau Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gtk/gtk.h>
#include <gconf/gconf-client.h>
#include <libgnomeui/gnome-window-icon.h>

#include "gnomecard-ui.h"

/*
 * Error Handling
 */

static void
gncal_ui_message_handler (const gchar *message, GtkMessageType type)
{
	GtkWidget *dialog;

	dialog = gtk_message_dialog_new (NULL, 0, type,
					 GTK_BUTTONS_OK,
					 "%s", message);
	g_signal_connect (G_OBJECT (dialog), "response",
			  G_CALLBACK (gtk_widget_destroy), NULL);
	gtk_widget_show (dialog);
}

static void
gncal_ui_standard_message_handler (const gchar *message)
{
	gncal_ui_message_handler (message, GTK_MESSAGE_INFO);
}

static void
gncal_ui_error_message_handler (const gchar *message)
{
	gncal_ui_message_handler (message, GTK_MESSAGE_WARNING);
}

/*
 * Setup
 */

void
gncard_ui_init (void)
{
	GConfClient *gconf;

	/* Error handling */

	g_set_print_handler    (gncal_ui_standard_message_handler);
	g_set_printerr_handler (gncal_ui_error_message_handler);

	gconf = gconf_client_get_default ();
	gconf_client_set_error_handling (gconf, GCONF_CLIENT_HANDLE_ALL);
	g_object_unref (G_OBJECT (gconf));

	/* Window icons */

	gnome_window_icon_set_default_from_file ("gnome-gnomecard.png");
}

/*
 * Error Handling
 */

void
gncard_ui_show_error (GtkWindow *parent, GError *error)
{
	GtkWidget *dialog;

	g_return_if_fail (parent == NULL || GTK_IS_WINDOW (parent));
	g_return_if_fail (error != NULL);

	dialog = gtk_message_dialog_new (parent,
					 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
					 error->message);
	g_signal_connect (G_OBJECT (dialog), "response",
			  G_CALLBACK (gtk_widget_destroy), NULL);
	gtk_widget_show (dialog);
}
